==> tine20-allinone_2019.12.5.tar.bz2: Addressbook/js/Addressbook-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: en_AU\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Business Contact Data"

, "Organisation / Unit"
: "Organisation / Unit"

, "Business Address"
: "Business Address"

, "Email"
: "Email"

, "Telephone Work"
: "Telephone Work"

, "Telephone Cellphone"
: "Telephone Cellphone"

, "Telephone Car"
: "Telephone Car"

, "Telephone Fax"
: "Telephone Fax"

, "Telephone Page"
: "Telephone Page"

, "URL"
: "URL"

, "Role"
: "Role"

, "Room"
: "Room"

, "Assistant"
: "Assistant"

, "Assistant Telephone"
: "Assistant Telephone"

, "Private Contact Data"
: "Private Contact Data"

, "Private Address"
: "Private Address"

, "Email Home"
: "Email Home"

, "Telephone Home"
: "Telephone Home"

, "Telephone Cellphone Private"
: "Telephone Cellphone Private"

, "Telephone Fax Home"
: "Telephone Fax Home"

, "URL Home"
: "URL Home"

, "Other Data"
: "Other Data"

, "Birthday"
: "Birthday"

, "Job Title"
: "Job Title"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "List"
 ,"Lists"

]
, "Percent"
: ""

, "Description"
: "Description"

, "Members"
: ""

, "Type"
: "Type"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Addressbook"
 ,"Addressbooks"

]
, "Contact, Contacts"
: [
  "Contact"
 ,"Contacts"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Country"

, "City"
: "City"

, "Postalcode"
: "Postalcode"

, "Region"
: "Region"

, "Street"
: "Street"

, "Street 2"
: "Street 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Country (private)"

, "City (private)"
: "City (private)"

, "Postalcode (private)"
: "Postalcode (private)"

, "Region (private)"
: "Region (private)"

, "Street (private)"
: "Street (private)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (private)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Note"

, "Last Name"
: "Last Name"

, "Display Name"
: "Display Name"

, "Full Name"
: "Full Name"

, "First Name"
: "First Name"

, "Middle Name"
: "Middle Name"

, "Title"
: "Title"

, "Suffix"
: "Suffix"

, "Company"
: "Company"

, "Unit"
: "Unit"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Job Role"

, "Salutation"
: "Salutation"

, "syncBackendIds"
: ""

, "Car phone"
: "Car phone"

, "Mobile"
: "Mobile"

, "Mobile (private)"
: "Mobile (private)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (private)"

, "Phone (private)"
: "Phone (private)"

, "Pager"
: "Pager"

, "Phone"
: "Phone"

, "Timezone"
: "Timezone"

, "Web"
: "Web"

, "URL (private)"
: "URL (private)"

, "Label"
: ""

, "Lists"
: "Lists"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Contact Information"

, "Company Address"
: "Company Address"

, "New Contact"
: "New Contact"

, "ID"
: ""

, "Name"
: "Name"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Import contacts"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Private"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Tags"

, "List Roles"
: ""

, "Street (Company Address)"
: "Street (Company Address)"

, "Street 2 (Company Address)"
: "Street 2 (Company Address)"

, "City (Company Address)"
: "City (Company Address)"

, "Region (Company Address)"
: "Region (Company Address)"

, "Postal Code (Company Address)"
: "Postal Code (Company Address)"

, "Country (Company Address)"
: "Country (Company Address)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Street (Private Address)"

, "Street 2 (Private Address)"
: "Street 2 (Private Address)"

, "City (Private Address)"
: "City (Private Address)"

, "Region (Private Address)"
: "Region (Private Address)"

, "Postal Code (Private Address)"
: "Postal Code (Private Address)"

, "Country (Private Address)"
: "Country (Private Address)"

, "Company Communication"
: "Company Communication"

, "Private Communication"
: "Private Communication"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (private)"

, "Web (private)"
: "Web (private)"

, "Contacts"
: "Contacts"

, "Addressbooks"
: "Addressbooks"

, "User Account"
: "User Account"

, "Quick Search"
: "Quick Search"

, "Postal Code"
: "Postal Code"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Creation Time"

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Enter description"

, "{0} must be given"
: ""

, "Member of List"
: "Member of List"

, "Map"
: "Map"

, "Company address"
: "Company address"

, "Private address"
: "Private address"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Personal Information"

, "Parse address"
: "Parse address"

, "Print contact"
: ""

, "Paste address"
: "Paste address"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "End token mode"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "All contacts"

, "Default Addressbook"
: "Default Addressbook"

, "The default addressbook for new contacts"
: "The default addressbook for new contacts"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on addressbook startup"
: "The default favorite which is loaded on addressbook startup"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contact duplicate check fields"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Contact salutations available"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing rules for addresses"

, "Path to a XML file with address parsing rules."
: "Path to a XML file with address parsing rules."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Contact VCARD import"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import list (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Contact CSV import from Outlook address book"

, "Contact CSV import from mac address book"
: "Contact CSV import from mac address book"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Contact import from Google address book"

, "manage shared addressbooks"
: "manage shared addressbooks"

, "Create new shared addressbook folders"
: "Create new shared addressbook folders"

, "manage shared addressbook favorites"
: "manage shared addressbook favorites"

, "Create or update shared addressbook favorites"
: "Create or update shared addressbook favorites"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's personal addressbook"

, "All contacts I have read grants for"
: "All contacts I have read grants for"

, "My company"
: "My company"

, "All coworkers in my company"
: "All coworkers in my company"

, "My contacts"
: "My contacts"

, "All contacts in my Addressbooks"
: "All contacts in my Addressbooks"

, "Last modified by me"
: "Last modified by me"

, "All contacts that I have last modified"
: "All contacts that I have last modified"

, "Internal Contacts"
: "Internal Contacts"

, "List"
: "List"

, "Addressbook"
: "Addressbook"

, "Contact"
: "Contact"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Map"

, "Preferred Address"
: ""

, "Personal Information"
: "Personal Information"

, "Salutation"
: "Salutation"

, "Title"
: "Title"

, "Short Name"
: ""

, "First Name"
: "First Name"

, "Middle Name"
: "Middle Name"

, "Last Name"
: "Last Name"

, "Company"
: "Company"

, "Unit"
: "Unit"

, "Display Name"
: "Display Name"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Job Title"

, "Birthday (private)"
: ""

, "Contact Information"
: "Contact Information"

, "Phone"
: "Phone"

, "Mobile"
: "Mobile"

, "Fax"
: "Fax"

, "Phone (private)"
: "Phone (private)"

, "Mobile (private)"
: "Mobile (private)"

, "Fax (private)"
: "Fax (private)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (private)"

, "Web"
: "Web"

, "Company Address"
: "Company Address"

, "Street"
: "Street"

, "Street 2"
: "Street 2"

, "Region"
: "Region"

, "Postal Code"
: "Postal Code"

, "City"
: "City"

, "Country"
: "Country"

, "Private Address"
: "Private Address"

, "Description"
: "Description"

, "Enter description"
: "Enter description"

, "Groups"
: ""

, "Parse address"
: "Parse address"

, "Print contact"
: ""

, "Paste address"
: "Paste address"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "End token mode"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Contact"
 ,"Contacts"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "New Contact"

, "Addressbook, Addressbooks"
: [
  "Addressbook"
 ,"Addressbooks"

]
, "ID"
: ""

, "Name"
: "Name"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Private"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Suffix"

, "Birthday"
: "Birthday"

, "Job Role"
: "Job Role"

, "Room"
: "Room"

, "Street (Company Address)"
: "Street (Company Address)"

, "Street 2 (Company Address)"
: "Street 2 (Company Address)"

, "City (Company Address)"
: "City (Company Address)"

, "Region (Company Address)"
: "Region (Company Address)"

, "Postal Code (Company Address)"
: "Postal Code (Company Address)"

, "Country (Company Address)"
: "Country (Company Address)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Street (Private Address)"

, "Street 2 (Private Address)"
: "Street 2 (Private Address)"

, "City (Private Address)"
: "City (Private Address)"

, "Region (Private Address)"
: "Region (Private Address)"

, "Postal Code (Private Address)"
: "Postal Code (Private Address)"

, "Country (Private Address)"
: "Country (Private Address)"

, "Company Communication"
: "Company Communication"

, "Private Communication"
: "Private Communication"

, "Web (private)"
: "Web (private)"

, "Contacts"
: "Contacts"

, "Addressbooks"
: "Addressbooks"

, "User Account"
: "User Account"

, "Quick Search"
: "Quick Search"

, "Type"
: "Type"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Creation Time"

, "Created By"
: ""

, "List, Lists"
: [
  "List"
 ,"Lists"

]
, "Lists"
: "Lists"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Import contacts"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Tags"

, "Full Name"
: "Full Name"

, "Postalcode"
: "Postalcode"

, "Street (private)"
: "Street (private)"

, "City (private)"
: "City (private)"

, "Region (private)"
: "Region (private)"

, "Postalcode (private)"
: "Postalcode (private)"

, "Country (private)"
: "Country (private)"

, "Email"
: "Email"

, "Car phone"
: "Car phone"

, "Pager"
: "Pager"

, "Email (private)"
: "Email (private)"

, "URL (private)"
: "URL (private)"

, "Note"
: "Note"

, "Timezone"
: "Timezone"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Company address"

, "Private address"
: "Private address"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "All contacts"

, "Default Addressbook"
: "Default Addressbook"

, "The default addressbook for new contacts"
: "The default addressbook for new contacts"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on addressbook startup"
: "The default favorite which is loaded on addressbook startup"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Contact duplicate check fields"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Contact salutations available"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing rules for addresses"

, "Path to a XML file with address parsing rules."
: "Path to a XML file with address parsing rules."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s's personal addressbook"

, "Business Contact Data"
: "Business Contact Data"

, "Organisation / Unit"
: "Organisation / Unit"

, "Business Address"
: "Business Address"

, "Telephone Work"
: "Telephone Work"

, "Telephone Cellphone"
: "Telephone Cellphone"

, "Telephone Car"
: "Telephone Car"

, "Telephone Fax"
: "Telephone Fax"

, "Telephone Page"
: "Telephone Page"

, "URL"
: "URL"

, "Role"
: "Role"

, "Assistant"
: "Assistant"

, "Assistant Telephone"
: "Assistant Telephone"

, "Private Contact Data"
: "Private Contact Data"

, "Email Home"
: "Email Home"

, "Telephone Home"
: "Telephone Home"

, "Telephone Cellphone Private"
: "Telephone Cellphone Private"

, "Telephone Fax Home"
: "Telephone Fax Home"

, "URL Home"
: "URL Home"

, "Other Data"
: "Other Data"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Contact CSV import from Outlook address book"

, "Contact CSV import from mac address book"
: "Contact CSV import from mac address book"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Contact VCARD import"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import list (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Contact import from Google address book"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Internal Contacts"

, "All contacts I have read grants for"
: "All contacts I have read grants for"

, "My company"
: "My company"

, "All coworkers in my company"
: "All coworkers in my company"

, "My contacts"
: "My contacts"

, "All contacts in my Addressbooks"
: "All contacts in my Addressbooks"

, "Last modified by me"
: "Last modified by me"

, "All contacts that I have last modified"
: "All contacts that I have last modified"

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "manage shared addressbooks"

, "Create new shared addressbook folders"
: "Create new shared addressbook folders"

, "manage shared addressbook favorites"
: "manage shared addressbook favorites"

, "Create or update shared addressbook favorites"
: "Create or update shared addressbook favorites"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Contact"

, "Addressbook"
: "Addressbook"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "List"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
